@@ -1,6 +1,5 @@
 """Utilities for asyncio-friendly file handling."""
 from .threadpool import open
+from . import tempfile
 
-__version__ = "0.5.0"
-
-__all__ = ["open"]
+__all__ = ["open", "tempfile"]
