@@ -13,6 +13,9 @@ class AsyncBase:
         """We are our own iterator."""
         return self
 
+    def __repr__(self):
+        return super().__repr__() + " wrapping " + repr(self._file)
+
     async def __anext__(self):
         """Simulate normal file iteration."""
         line = await self.readline()
